@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib
@@ -58,7 +58,8 @@ class AuthorizedCertificatesClientMeta(type):
     _transport_registry["grpc_asyncio"] = AuthorizedCertificatesGrpcAsyncIOTransport
 
     def get_transport_class(
-        cls, label: str = None,
+        cls,
+        label: str = None,
     ) -> Type[AuthorizedCertificatesTransport]:
         """Returns an appropriate transport class.
 
@@ -167,7 +168,9 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
         return self._transport
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -180,9 +183,13 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -191,9 +198,13 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -202,9 +213,13 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -213,10 +228,14 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -388,6 +407,7 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def list_authorized_certificates(
@@ -401,9 +421,7 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
         r"""Lists all SSL certificates the user is authorized to
         administer.
 
-
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
@@ -462,12 +480,20 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListAuthorizedCertificatesPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -483,8 +509,7 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
     ) -> certificate.AuthorizedCertificate:
         r"""Gets the specified SSL certificate.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
@@ -542,7 +567,12 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -557,8 +587,7 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
     ) -> certificate.AuthorizedCertificate:
         r"""Uploads the specified SSL certificate.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
@@ -616,7 +645,12 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -636,9 +670,7 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
         certificate. The certificate ``display_name`` may also be
         updated.
 
-
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
@@ -696,7 +728,12 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -711,8 +748,7 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
     ) -> None:
         r"""Deletes the specified SSL certificate.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
@@ -759,7 +795,10 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
 
         # Send the request.
         rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     def __enter__(self):
