@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -215,14 +215,13 @@ class AuthorizedDomainsAsyncClient:
         r"""Lists all domains the user is authorized to
         administer.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import appengine_admin_v1
 
-            def sample_list_authorized_domains():
+            async def sample_list_authorized_domains():
                 # Create a client
-                client = appengine_admin_v1.AuthorizedDomainsClient()
+                client = appengine_admin_v1.AuthorizedDomainsAsyncClient()
 
                 # Initialize request argument(s)
                 request = appengine_admin_v1.ListAuthorizedDomainsRequest(
@@ -232,7 +231,7 @@ class AuthorizedDomainsAsyncClient:
                 page_result = client.list_authorized_domains(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -272,12 +271,20 @@ class AuthorizedDomainsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListAuthorizedDomainsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
