@@ -601,9 +601,6 @@ class DomainMappingsAsyncClient:
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         request = appengine.DeleteDomainMappingRequest(request)
