@@ -810,9 +810,6 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Minor optimization to avoid making a copy if the user passes
