@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -60,6 +60,7 @@ class FirewallTransport(abc.ABC):
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
+        api_audience: Optional[str] = None,
         **kwargs,
     ) -> None:
         """Instantiate the transport.
@@ -86,10 +87,6 @@ class FirewallTransport(abc.ABC):
             always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                 be used for service account credentials.
         """
-        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
-        if ":" not in host:
-            host += ":443"
-        self._host = host
 
         scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}
 
@@ -111,6 +108,11 @@ class FirewallTransport(abc.ABC):
             credentials, _ = google.auth.default(
                 **scopes_kwargs, quota_project_id=quota_project_id
             )
+            # Don't apply audience if the credentials file passed from user.
+            if hasattr(credentials, "with_gdch_audience"):
+                credentials = credentials.with_gdch_audience(
+                    api_audience if api_audience else host
+                )
 
         # If the credentials are service account credentials, then always try to use self signed JWT.
         if (
@@ -123,11 +125,18 @@ class FirewallTransport(abc.ABC):
         # Save the credentials.
         self._credentials = credentials
 
+        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
+        if ":" not in host:
+            host += ":443"
+        self._host = host
+
     def _prep_wrapped_messages(self, client_info):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
             self.list_ingress_rules: gapic_v1.method.wrap_method(
-                self.list_ingress_rules, default_timeout=None, client_info=client_info,
+                self.list_ingress_rules,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.batch_update_ingress_rules: gapic_v1.method.wrap_method(
                 self.batch_update_ingress_rules,
@@ -135,25 +144,33 @@ class FirewallTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.create_ingress_rule: gapic_v1.method.wrap_method(
-                self.create_ingress_rule, default_timeout=None, client_info=client_info,
+                self.create_ingress_rule,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.get_ingress_rule: gapic_v1.method.wrap_method(
-                self.get_ingress_rule, default_timeout=None, client_info=client_info,
+                self.get_ingress_rule,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.update_ingress_rule: gapic_v1.method.wrap_method(
-                self.update_ingress_rule, default_timeout=None, client_info=client_info,
+                self.update_ingress_rule,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.delete_ingress_rule: gapic_v1.method.wrap_method(
-                self.delete_ingress_rule, default_timeout=None, client_info=client_info,
+                self.delete_ingress_rule,
+                default_timeout=None,
+                client_info=client_info,
             ),
         }
 
     def close(self):
         """Closes resources associated with the transport.
 
-       .. warning::
-            Only call this method if the transport is NOT shared
-            with other clients - this may cause errors in other clients!
+        .. warning::
+             Only call this method if the transport is NOT shared
+             with other clients - this may cause errors in other clients!
         """
         raise NotImplementedError()
 
@@ -217,5 +234,9 @@ class FirewallTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def kind(self) -> str:
+        raise NotImplementedError()
+
 
 __all__ = ("FirewallTransport",)
