@@ -434,9 +434,6 @@ class InstancesAsyncClient:
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         request = appengine.DeleteInstanceRequest(request)
