@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -21,7 +21,11 @@ from google.cloud.appengine_admin_v1.types import (
 
 
 __protobuf__ = proto.module(
-    package="google.appengine.v1", manifest={"Service", "TrafficSplit",},
+    package="google.appengine.v1",
+    manifest={
+        "Service",
+        "TrafficSplit",
+    },
 )
 
 
@@ -50,16 +54,51 @@ class Service(proto.Message):
             Mapping that defines fractional HTTP traffic
             diversion to different versions within the
             service.
+        labels (Mapping[str, str]):
+            A set of labels to apply to this service.
+            Labels are key/value pairs that describe the
+            service and all resources that belong to it
+            (e.g., versions). The labels can be used to
+            search and group resources, and are propagated
+            to the usage and billing reports, enabling
+            fine-grain analysis of costs. An example of
+            using labels is to tag resources belonging to
+            different environments (e.g., "env=prod",
+            "env=qa").
+            <p>Label keys and values can be no longer than
+            63 characters and can only contain lowercase
+            letters, numeric characters, underscores,
+            dashes, and international characters. Label keys
+            must start with a lowercase letter or an
+            international character. Each service can have
+            at most 32 labels.
         network_settings (google.cloud.appengine_admin_v1.types.NetworkSettings):
             Ingress settings for this service. Will apply
             to all versions.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    id = proto.Field(proto.STRING, number=2,)
-    split = proto.Field(proto.MESSAGE, number=3, message="TrafficSplit",)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    split = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="TrafficSplit",
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=4,
+    )
     network_settings = proto.Field(
-        proto.MESSAGE, number=6, message=ga_network_settings.NetworkSettings,
+        proto.MESSAGE,
+        number=6,
+        message=ga_network_settings.NetworkSettings,
     )
 
 
@@ -74,7 +113,7 @@ class TrafficSplit(proto.Message):
             request is sent to. The traffic selection
             algorithm will be stable for either type until
             allocations are changed.
-        allocations (Sequence[google.cloud.appengine_admin_v1.types.TrafficSplit.AllocationsEntry]):
+        allocations (Mapping[str, float]):
             Mapping from version IDs within the service to fractional
             (0.000, 1] allocations of traffic for that version. Each
             version can be specified only once, but some versions in the
@@ -93,8 +132,16 @@ class TrafficSplit(proto.Message):
         IP = 2
         RANDOM = 3
 
-    shard_by = proto.Field(proto.ENUM, number=1, enum=ShardBy,)
-    allocations = proto.MapField(proto.STRING, proto.DOUBLE, number=2,)
+    shard_by = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=ShardBy,
+    )
+    allocations = proto.MapField(
+        proto.STRING,
+        proto.DOUBLE,
+        number=2,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
